% dr = = dynamicresponse_constant(wave,P0)
% Purpose:  Estimating the impact force magnitude corresponding to the 
%           measured pile response from the plunging breakers
% ------------------------------------------------------------------------
% Variable          I/O      Description
% ------------------------------------------------------------------------
% wave              I        Defines the plunging breaker (1 or 2) 
% P0                I        Impact force magnitude
% dr                O        Calculated dynamic response 
% ------------------------------------------------------------------------
% May 2016
% Overn, Ida Haftun 
% Waage, Ida Fredsvik
% ------------------------------------------------------------------------


function dr = dynamicresponse_constant(wave,P0)

syms x t

h = 0.97;
D = 0.16;
Di = 0.15;
L = 1.53;

if wave == 1
    Cb = 0.196;
    Cg = 2.22;
    t1 = (13*D)/(64*Cg);
elseif wave == 2
    Cb = 0.211;
    Cg = 2.5;
    t1 = (13*D)/(64*Cg);
else
    Cb = 0.512;
    t1 = 0.028;
end

zb = Cb + h;

rhow = 1000; 
MM = 11.575/L;
M1 = 2*MM*h + 2*rhow*pi*(Di/2)^2*h;
M2 = MM*(L-h);
M3 = 5.080;
x3 = L + 0.10/2;

m = double((M3*x3*x3) + int((M2/(L-h))*x^2,x,h,L) + int((M1/h)*x^2,x,0,h));
k = 3788;
w0 = sqrt(k/m);

u1 = ((P0*(zb)^2)/(k*L))*(1 - cos(w0*t));
u0 = vpa(subs(u1,t,t1));
udot = diff(u1,t);
udot0 = subs(udot,t,t1);

u = zeros(1,2/0.001);
tt = zeros(1,2/0.001);


for i = 0:1:2000
    tt(i+1) = i*0.001;
     if tt(i+1) <= t1
         t = i*0.001;
         u(i+1) = ((P0*(zb)^2)/(k*L))*(1 - cos(w0*t));
     else
         t = tt(i+1)-t1;
         u(i+1) = (udot0/w0)*sin(w0*t) + u0*cos(w0*t);
     end
end

dr = (k*u*(1025/1000)*100^4)/10^9;

end