% [Cm, Cd] = calccoeff(T,umax)
% Purpose:  Calculate coefficients of the Morison equation
% ------------------------------------------------------------------------
% Variable          I/O      Description
% ------------------------------------------------------------------------
% T                 I        Period 
% umax              I        Maximum particle velocity under the crest
% Cm                O        Mass coefficient
% Cd                O        Drag coefficient
% ------------------------------------------------------------------------
% January 2016
% Overn, Ida Haftun 
% Waage, Ida Fredsvik
% ------------------------------------------------------------------------

function [Cm, Cd] = calccoeff(T,umax)

D = 16;
k = 5*10^-6;
KC = (T*umax)/D;
delta = k/D;

if delta < 10^-4
    Cds = 0.65;
elseif delta > 10^-2
    Cds = 1.05;
else
    Cds = (29 + 4*log10(delta))/20;
end

if KC > 60 && delta < 10^-4
    Cd = 0.65
elseif KC > 60 && delta > 10^-2
    Cd = 1.05
elseif KC < 12
    Cpi = 1.5 - 0.024*((12/Cds)-10);
    if KC < 0.75
        rake = Cpi - 1 - 2*(KC-0.75);
    elseif KC < 2 && KC >= 0.75
        rake = Cpi - 1;
    else
        rake = Cpi + 0.1*(KC-12);
    end
    Cd = Cds*rake
else
    KC/Cds
    prompt = 'Find rake value from graph in DNV-RP-C205 and enter it: ';
    rake = input(prompt);
    Cd = Cds*rake
end

if KC >= 20 && delta < 10^-4
    Cm = 1.6
elseif KC >= 20 && delta > 10^-2
    Cm = 1.2
else
    KC
    prompt = 'Find Ca value from graph in DNV-RP-C205 and enter it: ';
    Cm = input(prompt) + 1
end

end
