% [u,udot,y,umax] = dragormass(H,flowfile)
% Purpose:  Decide if the system is mass dominated, drag dominated or 
%           non-dominated and return values for further calculations 
% ------------------------------------------------------------------------
% Variable          I/O      Description
% ------------------------------------------------------------------------
% H                 I        Wave height
% flowfile          I        Output file from Stokes 5th program containing
%                            velocity and acceleration profiles
% u                 O        Horizontal particle velocity profile
% udot              O        Horizontal particle acceleration profile
% y                 O        Profile position along the vertical axis
% umax              O        Maximum particle velocity
% ------------------------------------------------------------------------
% January 2016
% Overn, Ida Haftun 
% Waage, Ida Fredsvik
% ------------------------------------------------------------------------

function [u,udot,y,umax] = dragormass(H,flowfile)

D = 16;
g = 9.81;
d = 97;

if D/H < 0.1
    u = (xlsread(flowfile,'B17:B117'))*sqrt(g*d);
    y = (xlsread(flowfile,'A17:A117'))*d;
    udot = (xlsread(flowfile,'E17:E117'))*g;
    umax = max(abs(u));
elseif D/H > 0.5
    u = (xlsread(flowfile,'B8441:B8541'))*sqrt(g*d);
    y = (xlsread(flowfile,'A8441:A8541'))*d;
    udot = (xlsread(flowfile,'E8441:E8541'))*g;
    umax = max(abs(u));
else
    [u,udot,y] = findmax(flowfile);
    umax = max(abs(u));
end

end