% [u,udot,y] = findmax(flowfile)
% Purpose:  Locate where the loads are maximum for a non-dominated system
% ------------------------------------------------------------------------
% Variable          I/O      Description
% ------------------------------------------------------------------------
% flowfile          I        Output file from Stokes 5th program containing
%                            velocity and acceleration profiles
% u                 O        Horizontal particle velocity profile
% udot              O        Horizontal particle acceleration profile
% y                 O        Profile position along the vertical axis
% ------------------------------------------------------------------------
% January 2016
% Overn, Ida Haftun 
% Waage, Ida Fredsvik
% ------------------------------------------------------------------------

function [u,udot,y] = findmax(flowfile)

g = 9.81;
d = 97.5;
Cd = 1;
Cm = 2;
rho = 1000;
D = 16;
scale = 100;

u1 = (xlsread(flowfile,'B17:B117')).*sqrt(g*d);
y1 = (xlsread(flowfile,'A17:A117')).*d;
udot1 = (xlsread(flowfile,'E17:E117')).*g;

u2 = (xlsread(flowfile,'B1785:B1885')).*sqrt(g*d);
y2 = (xlsread(flowfile,'A1785:A1885')).*d;
udot2 = (xlsread(flowfile,'E1785:E1885')).*g;

u3 = (xlsread(flowfile,'B3553:B3653')).*sqrt(g*d);
y3 = (xlsread(flowfile,'A3553:A3653')).*d;
udot3 = (xlsread(flowfile,'E3553:E3653')).*g;

u4 = (xlsread(flowfile,'B5321:B5421')).*sqrt(g*d);
y4 = (xlsread(flowfile,'A5321:A5421')).*d;
udot4 = (xlsread(flowfile,'E5321:E5421')).*g;

u5 = (xlsread(flowfile,'B7089:B7189')).*sqrt(g*d);
y5 = (xlsread(flowfile,'A7089:A7189')).*d;
udot5 = (xlsread(flowfile,'E7089:E7189')).*g;

u6 = (xlsread(flowfile,'B8857:B8957')).*sqrt(g*d);
y6 = (xlsread(flowfile,'A8857:A8957')).*d;
udot6 = (xlsread(flowfile,'E8857:E8957')).*g;

u7 = (xlsread(flowfile,'B10625:B10725')).*sqrt(g*d);
y7 = (xlsread(flowfile,'A10625:A10725')).*d;
udot7 = (xlsread(flowfile,'E10625:E10725')).*g;

u8 = (xlsread(flowfile,'B12393:B12493')).*sqrt(g*d);
y8 = (xlsread(flowfile,'A12393:A12493')).*d;
udot8 = (xlsread(flowfile,'E12393:E12493')).*g;

u9 = (xlsread(flowfile,'B14161:B14261')).*sqrt(g*d);
y9 = (xlsread(flowfile,'A14161:A14261')).*d;
udot9 = (xlsread(flowfile,'E14161:E14261')).*g;

u10 = (xlsread(flowfile,'B15929:B16029')).*sqrt(g*d);
y10 = (xlsread(flowfile,'A15929:A16029')).*d;
udot10 = (xlsread(flowfile,'E15929:E16029')).*g;

u11 = (xlsread(flowfile,'B17697:B17797')).*sqrt(g*d);
y11 = (xlsread(flowfile,'A17697:A17797')).*d;
udot11 = (xlsread(flowfile,'E17697:E17797')).*g;

fdrag1 = Cd*0.5*rho*D.*u1.*abs(u1);
fdrag2 = Cd*0.5*rho*D.*u2.*abs(u2);
fdrag3 = Cd*0.5*rho*D.*u3.*abs(u3);
fdrag4 = Cd*0.5*rho*D.*u4.*abs(u4);
fdrag5 = Cd*0.5*rho*D.*u5.*abs(u5);
fdrag6 = Cd*0.5*rho*D.*u6.*abs(u6);
fdrag7 = Cd*0.5*rho*D.*u7.*abs(u7);
fdrag8 = Cd*0.5*rho*D.*u8.*abs(u8);
fdrag9 = Cd*0.5*rho*D.*u9.*abs(u9);
fdrag10 = Cd*0.5*rho*D.*u10.*abs(u10);
fdrag11 = Cd*0.5*rho*D.*u11.*abs(u11);

fmass1 = Cm*rho*((pi*D^2)/4).*udot1;
fmass2 = Cm*rho*((pi*D^2)/4).*udot2;
fmass3 = Cm*rho*((pi*D^2)/4).*udot3;
fmass4 = Cm*rho*((pi*D^2)/4).*udot4;
fmass5 = Cm*rho*((pi*D^2)/4).*udot5;
fmass6 = Cm*rho*((pi*D^2)/4).*udot6;
fmass7 = Cm*rho*((pi*D^2)/4).*udot7;
fmass8 = Cm*rho*((pi*D^2)/4).*udot8;
fmass9 = Cm*rho*((pi*D^2)/4).*udot9;
fmass10 = Cm*rho*((pi*D^2)/4).*udot10;
fmass11 = Cm*rho*((pi*D^2)/4).*udot11;

mdrag1 = y1.*fdrag1;
mdrag2 = y2.*fdrag2;
mdrag3 = y3.*fdrag3;
mdrag4 = y4.*fdrag4;
mdrag5 = y5.*fdrag5;
mdrag6 = y6.*fdrag6;
mdrag7 = y7.*fdrag7;
mdrag8 = y8.*fdrag8;
mdrag9 = y9.*fdrag9;
mdrag10 = y10.*fdrag10;
mdrag11 = y11.*fdrag11;

mmass1 = y1.*fmass1;
mmass2 = y2.*fmass2;
mmass3 = y3.*fmass3;
mmass4 = y4.*fmass4;
mmass5 = y5.*fmass5;
mmass6 = y6.*fmass6;
mmass7 = y7.*fmass7;
mmass8 = y8.*fmass8;
mmass9 = y9.*fmass9;
mmass10 = y10.*fmass10;
mmass11 = y11.*fmass11;

f1 = (sum(fdrag1) + sum(fmass1))/scale^3;
f2 = (sum(fdrag2) + sum(fmass2))/scale^3;
f3 = (sum(fdrag3) + sum(fmass3))/scale^3;
f4 = (sum(fdrag4) + sum(fmass4))/scale^3;
f5 = (sum(fdrag5) + sum(fmass5))/scale^3;
f6 = (sum(fdrag6) + sum(fmass6))/scale^3;
f7 = (sum(fdrag7) + sum(fmass7))/scale^3;
f8 = (sum(fdrag8) + sum(fmass8))/scale^3;
f9 = (sum(fdrag9) + sum(fmass9))/scale^3;
f10 = (sum(fdrag10) + sum(fmass10))/scale^3;
f11 = (sum(fdrag11) + sum(fmass11))/scale^3;

m1 = (sum(mdrag1) + sum(mmass1))/scale^4;
m2 = (sum(mdrag2) + sum(mmass2))/scale^4;
m3 = (sum(mdrag3) + sum(mmass3))/scale^4;
m4 = (sum(mdrag4) + sum(mmass4))/scale^4;
m5 = (sum(mdrag5) + sum(mmass5))/scale^4;
m6 = (sum(mdrag6) + sum(mmass6))/scale^4;
m7 = (sum(mdrag7) + sum(mmass7))/scale^4;
m8 = (sum(mdrag8) + sum(mmass8))/scale^4;
m9 = (sum(mdrag9) + sum(mmass9))/scale^4;
m10 = (sum(mdrag10) + sum(mmass10))/scale^4;
m11 = (sum(mdrag11) + sum(mmass11))/scale^4;

mplot = [m1; m2; m3; m4; m5; m6; m7; m8; m9; m10; m11];
fplot = [f1; f2; f3; f4; f5; f6; f7; f8; f9; f10; f11];
phase = [0; 17; 34; 51; 68; 85; 102; 119; 136; 153; 170];

plot(phase,fplot)
figure
plot(phase,mplot)

ut = [u1, u2, u3, u4, u5, u6, u7, u8, u9, u10, u11];
udott = [udot1, udot2, udot3, udot4, udot5, udot6, udot7, udot8, udot9, udot10, udot11];
yt = [y1, y2, y3, y4, y5, y6, y7, y8, y9, y10, y11];

[f,h] = max(fplot);

u = ut(:,h);
udot = udott(:,h);
y = yt(:,h);

end