% [Force,Moment] = force(u,udot,y,Cd,Cm)
% Purpose:  Calculate force and moment by the Morison equation
% ------------------------------------------------------------------------
% Variable          I/O      Description
% ------------------------------------------------------------------------
% u                 I        Horizontal particle velocity profile
% udot              I        Horizontal particle acceleration profile
% y                 I        Profile positions along the vertical axis
% Cd                I        Drag coefficient
% Cm                I        Mass coefficient
% Force             O        Force by Morisons equation
% Moment            O        Moment by Morisons equation
% ------------------------------------------------------------------------
% January 2016
% Overn, Ida Haftun 
% Waage, Ida Fredsvik
% ------------------------------------------------------------------------

function [Force,Moment] = force(u,udot,y,Cd,Cm)

D = 16;
rho = 1000;
scale = 100;

fdrag = Cd*0.5*rho*D.*u.*abs(u);
fmass = Cm*rho*((pi*D^2)/4)*udot;
mdrag = y.*fdrag;
mmass = y.*fmass;

Force = (sum(fdrag)+sum(fmass))/(scale^3);
Moment = (sum(mdrag)+sum(mmass))/(scale^4);

end