% [T, Cmax, lambda, H, c, flowfile] = readinput()
% Purpose:  Read the output files from the Stokes 5th program and obtain
%           information used in further calculations
% ------------------------------------------------------------------------
% Variable          I/O      Description
% ------------------------------------------------------------------------
% T                 O        Period 
% Cmax              O        Maximum crest height
% lambda            O        Wave length
% H                 O        Wave height
% c                 O        Wave celerity
% flowfile          O        Output file from Stokes 5th program containing
%                            velocity and acceleration profiles
% ------------------------------------------------------------------------
% January 2016
% Overn, Ida Haftun 
% Waage, Ida Fredsvik
% ------------------------------------------------------------------------

function [T, Cmax, lambda, H, c, flowfile] = readinput()

g = 9.81;
d = 97;

solfile = 'Solution_crit_west.xlsx';
flowfile = 'Flowfield_crit_west.xlsx';
surffile = 'Surface_crit_west.xlsx';
% solfile = 'Solution4020.xlsx';
% flowfile = 'Flowfield4020.xlsx';
% surffile = 'Surface4020.xlsx';

lambda = (xlsread(solfile,'C16:C16'))*d;
H = (xlsread(solfile,'C17:C17'))*d;
c = (xlsread(solfile,'C19:C19'))*sqrt(g*d);
T = (xlsread(solfile,'C18:C18'))/(sqrt(g/d));
Cmax = -d + (max(xlsread(surffile,'B9:B109')))*d;

end