function [S,df] = powspec(x,y,dt)

% [S,df] = powspec(x,dt) - Calculation of one-sided power density spectrum
% of x as a function of frequency in Hz(!). The spectrum is so defined that
% its integral equals the variance of x. S(1) is the power density at frequ-
% ency df.
% [S,df] = powspec(x,y,dt) gives the one-sided cross power density function
% of x and y - usually complex. The real part of the integral of the cross-
% spectrum equals the covariance of between x and y.
%
% K.E.Kaasen, Marintek, Trondheim, August 1992

N = length(x);
X = fft(x)/N; % Fourier transform (Should a warning
% .. be given when N is not a power of 2 ?)

if nargin == 2,
    dt = y;
    Y = X; % Auto spectrum is to be computed
elseif nargin == 3
    if length(y) ~= N 
        error('Input functions must have equal lengths')
    end
    Y = fft(y)/N;
else
    error('Wrong number of arguments')
end

df = 1/(N*dt);

% The first element in X is the zero-frequency value (constant term).
% If the number of elements N is even element N/2+1 is the Nyquist fre-
% quency. If N is odd there is no Nyquist frequency.
%
% Select the part of X that corresponds to positive frequencies.
% Nhi is the highest positive frequency. 2 is the lowest (1 is the constant
% term)

if mod(N,2) == 0 
    Nhi = N/2+1; 
else
    Nhi = (N+1)/2;
end;
%
S = 2*X(2:Nhi).*conj(Y(2:Nhi))/df; % Raw spectral densities
% S(1) is the spectral density at frequency dw. S(Nhi) corresponds to Nhi*dw.
end