% Purpose:  Designing a wavetrain resulting in a plunging breaker at a
%           predefined location
% ------------------------------------------------------------------------
% Functions: kiteration
%           calculate_cg
%           biesel_flap
%           write2mcl
% ------------------------------------------------------------------------
% January 2016
% Overn, Ida Haftun 
% Waage, Ida Fredsvik
% ------------------------------------------------------------------------


testid = 1091;

h = 0.978;          %water depth
w_min = 3.9;        %min wave frequency
w_max = 5.5;        %max wave frequency
xf = 17.5;          %distance to focus point
dt = 1/50;
nramp = 3;

n = 1000;

w_vec = linspace(w_min,w_max,n);
k_vec = kiteration(w_vec,h);
Cg_vec = calculate_cg(k_vec,h);
tf = xf/Cg_vec(end);
t_vec = tf - xf./Cg_vec;
a_vec = (0.5*0.7*0.88./(k_vec)).*(tanh(0.833*h*k_vec./0.88));
Cg1_vec = Cg_vec.*(1-0.5*(k_vec.*a_vec).^2);

t = [min(t_vec):dt:max(t_vec)];
a = interp1(t_vec,a_vec,t);
w = interp1(t_vec,w_vec,t);
k = interp1(t_vec,k_vec,t);
Cg = interp1(t_vec,Cg1_vec,t);
N = length(t);
wt = cumsum(w*dt);
theta = w_vec(1)*(tf-t_vec(1)) - k_vec(1)*xf;

T_s = 2*pi/w(1);                T_e = 2*pi/w(end);
n_s = round(nramp*T_s/dt);      n_e = round(nramp*T_e/dt);
t_s = dt*[-n_s:-1];             t_e = dt*[1:n_e];
a_s = ([0:n_s-1]/n_s)*a(1);     a_e = (1-[0:n_e-1]/n_e)*a(end);
w_s = ones(1,n_s)*w(1);         w_e = ones(1,n_e)*w(end);
k_s = ones(1,n_s)*k(1);         k_e = ones(1,n_e)*k(end);
Cg_s = ones(1,n_s)*Cg(1);       Cg_e = ones(1,n_e)*Cg(end);
wt_s = w(1)*t_s+wt(1);          wt_e = w(end)*t_e+wt(end);
t_e = t_e + t(end);

lambda_b = 2*pi/k(end);
t_f = xf/Cg(1);

t = [t_s,t,t_e];
a = [a_s,a,a_e];
w = [w_s,w,w_e];
k = [k_s,k,k_e];
Cg = [Cg_s,Cg,Cg_e];
wt = [wt_s,wt,wt_e];

HS = biesel_flap(k,h,0.08);
wm_signal = a.*cos(wt-theta)./HS;

wave_wm = a.*cos(wt-theta);
wave_pile = a.*cos(wt-k*17);

wm_signal = (wm_signal/(h-0.08))*(h-0.08+0.4);

plot(t,wave_wm,'b')
grid on, hold on
title('\fontsize{16}Wavetrain 1')
xlabel('\fontsize{14}Time (sec)')
ylabel('\fontsize{14}Surface Elevation (m)')
charid  = num2str(testid);
savename  = [charid '.dat'];

Data      = zeros(length(wm_signal),6);
Data(:,1) = wm_signal*1000;
write2mcl(['mcl/' savename],Data);

