% HS = biesel_flap(k,h,h0)
% Purpose:  Calculating the Biesel transfer function for flap type 
%           wave maker 
% ------------------------------------------------------------------------
% Variable   I/O        Description
% ------------------------------------------------------------------------
% HS        O       Transfer function
% k         I       Wave number
% h         I       Water depth
% h0        I       Distance between hinge and flume bottom
% ------------------------------------------------------------------------
% January 2016
% Overn, Ida Haftun 
% Waage, Ida Fredsvik
% ------------------------------------------------------------------------

function HS = biesel_flap(k,h,h0)

kh = k*h;
h1 = h-h0;

HS1 = 2./(k*h1);
HS2 = sinh(kh).*(h1*k.*sinh(kh)-cosh(kh)+cosh(k*h0));
HS3 = sinh(kh).*cosh(kh)+kh;

HS = HS1.*HS2./HS3;

end