% S = donelan(w, Hs, Tp)
% Purpose:  Calculating the Donelan wave spectrum for a given sea state
% ------------------------------------------------------------------------
% Variable   I/O        Description
% ------------------------------------------------------------------------
% S         O       Wave spectrum
% w         I       Wave frequency
% Hs        I       Hs-value of the sea state
% Tp        I       Tp-value of the sea state
% ------------------------------------------------------------------------
% January 2016
% Overn, Ida Haftun 
% Waage, Ida Fredsvik
% ------------------------------------------------------------------------


function S = donelan(w, Hs, Tp)

g = 9.81;
wp = 2*pi/Tp;
m0 = Hs^2/16;

beta = 200*g^(-1.571)*m0^(0.786)*Tp^(-3.143);
gamma = 6.489 + 6*log10(2.649E7*g^(-2.857)*m0^(1.429)*Tp^(-5.714));
sigma = 0.08 + 6.940E-26*g^(8.571)*m0^(-4.287)*Tp^(17.142);
delta = exp(-((w-wp).^2)/(2*sigma^2*wp^2));

S = beta*g^2*wp^(-1)*w.^(-4).*exp(-(w./wp).^(-4)).*gamma.^delta;

end