% S = jonswap(w,Hs,Tp,gamma)
% Purpose:  Calculating the JONSWAP wave spectrum for a given sea state
% ------------------------------------------------------------------------
% Variable          I/O      Description
% ------------------------------------------------------------------------
% w                 I        Circular frequency 
% Hs                I        Significant waveheight in the JONSWAP spectrum
% Tp                I        Peak period in the JONSWAP specturm
% gamma             I        Gamma-parameter in the JONSWAP spectrum
% S                 O        Calculated wave spectrum 
% ------------------------------------------------------------------------
% January 2016
% Overn, Ida Haftun 
% Waage, Ida Fredsvik
% ------------------------------------------------------------------------

function S = jonswap(w,Hs,Tp,gamma)

wp = 2*pi/Tp;
S = zeros(1,length(w));

for i = 1:length(w)
    if w(i) <= wp
        sigma = 0.07;
    else
        sigma = 0.09;
    end

    S_PM = (5/16)*(Hs^2*wp^4)/(w(i)^5)*exp(-(5/4)*(w(i)/wp)^-4);
    A = 1-0.287*log(gamma);

    S(i) = A*S_PM*gamma^(exp(-0.5*((w(i)-wp)/(sigma*wp))^2));
end

end