% Save to mcl binary format
%
% write2mcl(filename,data,dT)
%   
%   filename: name of output file
%   data:     a mx6 matrix with the actual position data
%   dT:       time step. Default is 0.01 s
%
% The format of the file is:
%   Timestep in ms (int),
%   Nos. Channels (int), 
%   positon channel 1 at first time step (float), 
%    positon channel 2 at first time step (float),
%                     |
%    positon channel N at first time step (float),
%    positon channel 1 at second time step (float),
%                     |
%                     |
%    positon channel N at last time step (float)
%
%    This is the MCL format, first used for sloshing in 2003
%
%
function write2mcl(filename,data,dT);

% Filename
[pathstr,name,ext]=fileparts(filename);
if isempty(ext)
    filename=[filename,'.dat'];
end
disp(['  Filename : ',filename]);

% Signal
if nargin<3
    dT=0.01;
end
[m,n]=size(data);
if n~=6
    data=data';
    [m,n]=size(data);
    if n~=6
        error('Input data must have either 6 rows or 6 columns');
        return;
    end
end
vel=(data(2:end,:)-data(1:end-1,:))/dT;
acc=(vel(2:end,:)-vel(1:end-1,:))/dT;

% Display
% disp(['  Duration  [s]: ',num2str(m*dT)]);
% disp(sprintf(' %40s %15s%15s%15s%15s%15s%15s',' ','X','Y','U','C','Z','W'));
% disp(['  Max Amplitude            [m]: ',num2str(max(abs(data)),'%10.4f')]);
% disp(['  Max Velocity             [m/s]: ',num2str(abs(max(abs(vel))),'%10.4f')]);
% disp(['  Max Acceleration [m/s^2]: ',num2str(abs(max(abs(acc))),'%10.4f')]);
% disp(' ');

    % Open an write to file. Note that fwrite writes columnwise
    fid=fopen(filename,'wb');
   
    head=[round(dT*1000);6];
    body=data';
    
    count=fwrite(fid,head,'int32');
    count=count+fwrite(fid,body,'float32');
    
    fclose(fid);
    
    disp([' Wrote ',num2str(count),' elements']);
    
    