function kk=findk(T,h)
% Matlab function
% function kk=findk(T,h)
%     
%    T          :  Wave period
%    h          :  water depth
%
% Purpose:
%     Find k, given omega, from the dispersion
%     relation omega^2=gk tanh kh
%
% June 2006, Trygve Kristiansen, CeSOS
%

g=9.81;
omega=2*pi/T;

epsilon=10^-8;
k=omega^2/g;
k0=k+2*epsilon;
while (abs(k-k0))>epsilon
  k0=k;
  f=g*k0*tanh(k0*h)-omega^2;
  fder=g*(tanh(k0*h)+k0/cosh(k0*h)^2);
  k=k0-f/fder;  
end

kk=k;