% [fitresult_my, fitresult_std] = conditional(scatter)
% Purpose:  Calculating the two parameters for the lognormal distribution
%           for Tp. Utilizes curvefitting 
% ------------------------------------------------------------------------
% Variable          I/O      Description
% ------------------------------------------------------------------------
% fitresult_my      O        Curvefitting results for expected value 
% fitresult_std     O        Curvefitting results for std
% scatter           I        scatterdiagram
% ------------------------------------------------------------------------
% Calling functions:[fitresult_my, gof_my] = my_fit(h_plot, my_lntp);
%                   [fitresult_std, gof_sig] = std_fit(h_plot, std_lntp);
% ------------------------------------------------------------------------
% January 2016
% Overn, Ida Haftun 
% Waage, Ida Fredsvik
% ------------------------------------------------------------------------

function [fitresult_my, fitresult_std] = conditional(scatter)

[m, n] = size(scatter);

my_lntp = zeros(1,m);
std_lntp = zeros(1,m);
h_plot = zeros(1,m);

for i = 1:m
    h_plot(i) = i/2;
    my_sum = 0;
    sig_sum = 0;
    for j = 1:n
        my_sum = my_sum + scatter(i,j)*log(j);
    end
    my_lntp(i) = my_sum/sum(scatter(i,:));
    for j = 1:n
        sig_sum = sig_sum + scatter(i,j)*(log(j) - my_lntp(i))^2;
    end
    std_lntp(i) = real(sqrt(sig_sum/(sum(scatter(i,:)) - 1)));
end

assignin('base', 'h_plot', h_plot);     %Assigning variables to base 
assignin('base', 'my_lntp', my_lntp);   %Assigning variables to base 
assignin('base', 'std_lntp', std_lntp); %Assigning variables to base 

%Calculating the fitted curves for std and my. 
[fitresult_my, gof_my] = my_fit(h_plot, my_lntp);
[fitresult_std, gof_sig] = std_fit(h_plot, std_lntp);

end
