% [h, t] = contour(scatter, Hs, Tp)
% Purpose:  Function that calculates the ULS ans ALS contour lines. Assign
%           h and t coordinates to output variables based on 
%           scatterdiagram and values from input file
% ------------------------------------------------------------------------
% Variable   I/O        Description
% ------------------------------------------------------------------------
% h          O        H-coordinates for contours 
% t          O        T-coordinates for contours
% scatter    I        scatterdiagram
% Hs         I        Hs-values from hindcasting
% Tp         I        Tp-values from hindcasting
% ss         I        Annual number of sea states
% ------------------------------------------------------------------------
% Calling functions:marginal(Hs,scatter)    - parameters for marginal
%                   conditional(scatter)    - parameters for lognormal
% ------------------------------------------------------------------------
% January 2016
% Overn, Ida Haftun 
% Waage, Ida Fredsvik
% ------------------------------------------------------------------------

function [h, t] = contour(scatter, Hs, Tp, ss)

u1 = zeros(2,360);
u2 = zeros(2,360);

[l, a, b] = marginal(Hs);   
[my, std] = conditional(scatter);

q = [10^-2; 10^-4];         %ULS ans ALS prob.levels

beta = -norminv(q./ss);   %transforms q into u space

for j = 1:360               %u-space calculations
    theta = j*pi/180;
    u1(1,j) = beta(1)*cos(theta);
    u2(1,j) = beta(1)*sin(theta);
    u1(2,j) = beta(2)*cos(theta);
    u2(2,j) = beta(2)*sin(theta);
end

for i = 1:2                 %calculating H and T coordinates 
    for j = 1:360 
        h(i,j) = l+a*(-log(1-normcdf(u1(i,j)))).^(1/b);
        t(i,j) = exp(my(h(i,j)) + u2(i,j)*std(h(i,j)));
    end
end

end
