% [N_Hs, N_Tp, S_Hs, S_Tp, E_Hs, E_Tp, W_Hs, W_Tp] = direction(dir, Hs, Tp)
% Purpose:  Dividing the sea states expressed in terms of Hs and Tp 
%           values into sectors for waves propagating from different
%           directions
% ------------------------------------------------------------------------
% Variable   I/O        Description
% ------------------------------------------------------------------------
% dir       I       Mean direction of the waves within the sea states 
% Hs        I       Hs-values from hindcasting
% Tp        I       Tp-values from hindcasting
% N_Hs      O       Hs-values for waves propagating from north
% N_Tp      O       Tp-values for waves propagating from north 
% S_Hs      O       Hs-values for waves propagating from south
% S_Tp      O       Tp-values for waves propagating from south 
% W_Hs      O       Hs-values for waves propagating from west
% W_Tp      O       Tp-values for waves propagating from west 
% ------------------------------------------------------------------------
% January 2016
% Overn, Ida Haftun 
% Waage, Ida Fredsvik
% ------------------------------------------------------------------------

function [N_Hs, N_Tp, S_Hs, S_Tp, E_Hs, E_Tp, W_Hs, W_Tp] = direction(dir, Hs, Tp)

N_Hs = []; N_Tp = []; 
S_Hs = []; S_Tp = [];  
E_Hs = []; E_Tp = [];  
W_Hs = []; W_Tp = [];  

for i = 1:length(dir)
    if dir(i) > 310 || dir(i) <= 30
        N_Hs = [N_Hs, Hs(i)];
        N_Tp = [N_Tp, Tp(i)];
    elseif dir(i) > 150 && dir(i) <= 225
        S_Hs = [S_Hs, Hs(i)];
        S_Tp = [S_Tp, Tp(i)];
    elseif dir(i) > 225 && dir(i) <= 310 
        W_Hs = [W_Hs, Hs(i)];
        W_Tp = [W_Tp, Tp(i)];
    else 
        E_Hs = [E_Hs, Hs(i)];
        E_Tp = [E_Tp, Tp(i)];
    end
end

end

