% [lambda, alpha, beta] = marginal(Hs,scatter)
% Purpose:  Calculate the three weibull parameters for the marginal
%           distribution of Hs 
% ------------------------------------------------------------------------
% Variable   I/O        Description
% ------------------------------------------------------------------------
% lambda    O       Lambda-parameter 
% alpha     O       Alpha-parameter
% beta      O       Beta-parameter   
% Hs        I       Hs-values from hindcasting
% ------------------------------------------------------------------------
% January 2016
% Overn, Ida Haftun 
% Waage, Ida Fredsvik
% ------------------------------------------------------------------------

function [lambda, alpha, beta] = marginal(Hs)

syms B a                %symbolic variables

mHs = mean(Hs);         %first moment of Hs
SHs = var(Hs);          %second moment of Hs
gHs = skewness(Hs);     %third moment of Hs

gam1 = gamma(1+3/B) - 3*gamma(1+1/B)*gamma(1+2/B) + 2*gamma(1+1/B)^3;
gam2 = (gamma(1+2/B) - gamma(1+1/B)^2)^(3/2);

beta = double(vpasolve(gam1/gam2 == gHs, B, [0,inf]));
sig = a^2*(gamma(1+2/beta) - gamma(1+1/beta)^2);
alpha = abs(double(vpasolve(sig == SHs, a, [0, inf])));
lambda = mHs - alpha*gamma(1+1/beta);

Hss = sort(Hs);
p_Hs = zeros(1,length(Hs));
for i = 1:length(Hs)
    p_Hs(i) = i/(length(Hs)+1);
end

h_plotting = [0:0.01:max(Hs)+4];
p_w = 1-exp(-((h_plotting-lambda)./alpha).^beta);

end

