% [hsq, tpq] = qprob(Hs, scatter)
% Purpose:  Calculating the Hs-values corresponding to the ULS and ALS
%           probability value and the corresponding 90% interval for Tp
% ------------------------------------------------------------------------
% Variable          I/O      Description
% ------------------------------------------------------------------------
% scatter           I        Scatterdiagram
% Hs                I        Hs-values from hindcasting
% ss                I        Annual number of sea states
% hsq               O        Hs-values corresponding to ULS and ALS
% tpq               O        90% intervals for Tp
% ------------------------------------------------------------------------
% Calling functions:    [l, a, b] = marginal(Hs,scatter);   
%                       [my, std] = conditional(scatter);   
% ------------------------------------------------------------------------
% January 2016
% Overn, Ida Haftun 
% Waage, Ida Fredsvik
% ------------------------------------------------------------------------

function [hsq, tpq] = qprob(Hs, scatter, ss)

syms hsqcrit                        %creating a symbolic variable 

hsq = zeros(1,2);
tpq = zeros(2,2);

[l, a, b] = marginal(Hs);           %calculating weibull parameters
[my, std] = conditional(scatter);   %calculating lognormal parameters 

q = [10^-2, 10^-4];                 %annual q-probability values

for i = 1:2
    hsq(i) = double(vpasolve(1-exp(-((hsqcrit - l)/a)^b) == 1-q(i)/ss,...
        hsqcrit, [0,50]));
    tpq(i,1) = exp(my(hsq(i)) + 0.05*std(hsq(i)));
    tpq(i,2) = exp(my(hsq(i)) + 0.95*std(hsq(i)));
end

end